@@ -86,7 +86,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -145,6 +145,12 @@
 #else
 #  define KTEXTWIDGETS_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KTEXTWIDGETS_DEPRECATED_VERSION_5(minor, text)      KTEXTWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION(major, minor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -210,7 +216,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -220,7 +226,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -269,6 +275,12 @@
 #else
 #  define KTEXTWIDGETS_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KTEXTWIDGETS_DEPRECATED_VERSION_5(minor, text)      KTEXTWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION(major, minor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
